summaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/ulogd/ulogd.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/include/ulogd/ulogd.h b/include/ulogd/ulogd.h
index 89b757a..88de3ca 100644
--- a/include/ulogd/ulogd.h
+++ b/include/ulogd/ulogd.h
@@ -80,7 +80,8 @@ enum ulogd_dtype {
ULOGD_DTYPE_RAW = 0x0002, /* raw packet data */
ULOGD_DTYPE_PACKET = 0x0004, /* packet metadata */
ULOGD_DTYPE_FLOW = 0x0008, /* flow metadata */
- ULOGD_DTYPE_SINK = 0x0010, /* sink of data, no output keys */
+ ULOGD_DTYPE_SUM = 0x0010, /* sum metadata */
+ ULOGD_DTYPE_SINK = 0x0020, /* sink of data, no output keys */
};
/* structure describing an input / output parameter of a plugin */